@@ -1,4 +1,4 @@
-# Copyright (C) 2014 Ivan E. Cao-Berg
+# Copyright (C) 2014-2022 Ivan E. Cao-Berg
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published
@@ -14,7 +14,3 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301, USA.
-
-import search
-
-__all__ = [ "search" ]
